# 2.5.0

- Две последние минутные свечи, по всем тикерам рынка.
- Последние сделки по всем тикерам рынка.
- Расширен список доступных периодов для свечей.
- Python 3.12; аннотаций типов (typing).
- (Beta) Функция ресемплирования суперсвечей.
- (Beta) Получение данных через WebSocket.
